@@ -16,8 +16,8 @@ import (
 	"github.com/hashicorp/waypoint/internal/pkg/flag"
 	"github.com/hashicorp/waypoint/internal/plugin"
 	runnerpkg "github.com/hashicorp/waypoint/internal/runner"
-	pb "github.com/hashicorp/waypoint/internal/server/gen"
 	"github.com/hashicorp/waypoint/internal/serverclient"
+	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 )
 
 type RunnerAgentCommand struct {
@@ -44,6 +44,15 @@ type RunnerAgentCommand struct {
 	// If this is an ODR runner, this should be the ODR profile that it was created
 	// from.
 	flagOdrProfileId string
+
+	// Cookie to use for API requests. Importantly, this enables runner adoption.
+	flagCookie string
+
+	// State directory for runner.
+	flagStateDir string
+
+	// Labels for the runner.
+	flagLabels map[string]string
 }
 
 // This is how long a runner in ODR mode will wait for its job assignment before
@@ -82,17 +91,24 @@ func (c *RunnerAgentCommand) Run(args []string) int {
 	}
 	client := pb.NewWaypointClient(conn)
 
+	// Build the values we'll show in the runner config table
+	infoValues := []terminal.NamedValue{
+		{Name: "Server address", Value: conn.Target()},
+	}
+	if c.flagODR {
+		infoValues = append(infoValues, terminal.NamedValue{
+			Name: "Type", Value: "on-demand",
+		})
+	} else {
+		infoValues = append(infoValues, terminal.NamedValue{
+			Name: "Type", Value: "remote",
+		})
+	}
+
 	// Output information to the user
 	c.ui.Output("Runner configuration:", terminal.WithHeaderStyle())
-	c.ui.NamedValues([]terminal.NamedValue{
-		{Name: "Server address", Value: conn.Target()},
-	})
+	c.ui.NamedValues(infoValues)
 	c.ui.Output("Runner logs:", terminal.WithHeaderStyle())
-	if c.flagODR {
-		c.ui.Output("Operating as an On-demand Runner")
-	} else {
-		c.ui.Output("Operating as a static Runner")
-	}
 
 	c.ui.Output("")
 
@@ -129,12 +145,18 @@ func (c *RunnerAgentCommand) Run(args []string) int {
 		runnerpkg.WithClient(client),
 		runnerpkg.WithLogger(log.Named("runner")),
 		runnerpkg.WithDynamicConfig(c.flagDynConfig),
+		runnerpkg.WithStateDir(c.flagStateDir),
+		runnerpkg.WithLabels(c.flagLabels),
 	}
 
 	if c.flagId != "" {
 		options = append(options, runnerpkg.WithId(c.flagId))
 	}
 
+	if c.flagCookie != "" {
+		options = append(options, runnerpkg.WithCookie(c.flagCookie))
+	}
+
 	if c.flagODR {
 		options = append(options,
 			runnerpkg.WithODR(c.flagOdrProfileId),
@@ -152,14 +174,14 @@ func (c *RunnerAgentCommand) Run(args []string) int {
 		return 1
 	}
 
-	// Start the runner
-	log.Info("starting runner", "id", runner.Id())
-	if err := runner.Start(); err != nil {
-		log.Error("error starting runner", "err", err)
-		return 1
-	}
+	// We always defer the close, but in happy paths this should be a noop
+	// because we do a close later in this function more gracefully.
+	defer runner.Close()
 
 	// If we have a liveness address setup, start the liveness server.
+	// We need to do this before starting the runner, because the runner
+	// startup might block on waiting for adoption, and we need
+	// the underlying platform to keep the runner alive until that completes
 	if addr := c.flagLivenessTCPAddr; addr != "" {
 		ln, err := net.Listen("tcp", addr)
 		if err != nil {
@@ -192,6 +214,13 @@ func (c *RunnerAgentCommand) Run(args []string) int {
 		}()
 	}
 
+	// Start the runner
+	log.Info("starting runner", "id", runner.Id())
+	if err := runner.Start(ctx); err != nil {
+		log.Error("error starting runner", "err", err)
+		return 1
+	}
+
 	// Accept jobs in goroutine so that we can interrupt it.
 	ctx, cancel := context.WithCancel(ctx)
 
@@ -230,6 +259,13 @@ func (c *RunnerAgentCommand) Run(args []string) int {
 					// a short sleep to allow the server to come back online.
 					log.Warn("server unavailable, sleeping before retry")
 					time.Sleep(2 * time.Second)
+
+				case codes.PermissionDenied, codes.Unauthenticated:
+					// The runner was rejected after the fact or our token
+					// was revoked. We exit and expect an init process or
+					// something to restart us if they want to retry.
+					log.Error("no permission to request a job, exiting")
+					return
 				}
 			}
 		}
@@ -285,6 +321,29 @@ func (c *RunnerAgentCommand) Flags() *flag.Sets {
 			Usage:  "The ID of the odr profile used to create the task that is running this runner.",
 			Hidden: true,
 		})
+
+		f.StringVar(&flag.StringVar{
+			Name:   "cookie",
+			Target: &c.flagCookie,
+			Usage: "The cookie value of the server to validate API requests. " +
+				"This is required for runner adoption. If you do not already have a " +
+				"runner token, this must be set.",
+			EnvVar: serverclient.EnvServerCookie,
+		})
+
+		f.StringVar(&flag.StringVar{
+			Name:   "state-dir",
+			Target: &c.flagStateDir,
+			Usage: "Directory to store state between restarts. This is optional. If " +
+				"this is set, then a runner can restart without re-triggering the adoption " +
+				"process.",
+		})
+
+		f.StringMapVar(&flag.StringMapVar{
+			Name:   "label",
+			Target: &c.flagLabels,
+			Usage:  "Labels to set for this runner in 'k=v' format. Can be specified multiple times.",
+		})
 	})
 }
 
@@ -304,7 +363,27 @@ func (c *RunnerAgentCommand) Help() string {
 	return formatHelp(`
 Usage: waypoint runner agent [options]
 
-  Run a runner for executing remote operations.
+  Run a remote runner for executing remote operations.
+
+  Runners are named or identified via the ID and the label set. The ID
+  can be manually specified or automatically generated. The label set is
+  specified using "-label" flags.
+
+  A runner can be registered with the server in two ways. First, a
+  runner token can be created with "waypoint runner token" and used with
+  this command (using the WAYPOINT_SERVER_TOKEN environment variable,
+  "waypoint context", etc.). This will allow the runner to begin accepting
+  jobs immediately since it is preauthorized.
+
+  The second approach is to specify only the cookie value (acquired using
+  the "waypoint server cookie" command) and the server address. This will
+  trigger a process that puts the runner in a pending state until a human
+  manually verifies it. This is useful for easily installing runners.
+
+  The "-state-dir" flag is optional, but important. This flag allows runners
+  to restart gracefully without regenerating a new ID or losing a rotated
+  authentication token. Runners can be run without a state directory but it is
+  not generally recommended.
 
 ` + c.Flags().Help())
 }
