@@ -22,18 +22,24 @@ import (
 	"github.com/hashicorp/go-hclog"
 	hznhub "github.com/hashicorp/horizon/pkg/hub"
 	hzntest "github.com/hashicorp/horizon/pkg/testutils/central"
+
 	wphzn "github.com/hashicorp/waypoint-hzn/pkg/server"
+	"github.com/hashicorp/waypoint/internal/server/boltdbstate"
+	"github.com/hashicorp/waypoint/pkg/server/singleprocess"
+
 	"github.com/hashicorp/waypoint/internal/telemetry"
+	serverpkg "github.com/hashicorp/waypoint/pkg/server"
+
 	"github.com/mitchellh/go-testing-interface"
 	"github.com/posener/complete"
 	"github.com/stretchr/testify/require"
 	bolt "go.etcd.io/bbolt"
 
 	"github.com/hashicorp/waypoint-plugin-sdk/terminal"
+
 	"github.com/hashicorp/waypoint/internal/pkg/cert"
 	"github.com/hashicorp/waypoint/internal/pkg/flag"
 	"github.com/hashicorp/waypoint/internal/server"
-	"github.com/hashicorp/waypoint/internal/server/singleprocess"
 	"github.com/hashicorp/waypoint/internal/serverconfig"
 )
 
@@ -160,9 +166,19 @@ func (c *ServerRunCommand) Run(args []string) int {
 		TLSSkipVerify: c.flagAdvertiseTLSSkipVerify,
 	}
 
+	// Initialize our state
+	state, err := boltdbstate.New(log, db)
+	if err != nil {
+		c.ui.Output(
+			"Error initializing boltdb state backend: %s", err.Error(),
+			terminal.WithErrorStyle(),
+		)
+		return 1
+	}
+
 	// Create our server
 	impl, err := singleprocess.New(
-		singleprocess.WithDB(db),
+		singleprocess.WithState(state),
 		singleprocess.WithConfig(&c.config),
 		singleprocess.WithLogger(log.Named("singleprocess")),
 		singleprocess.WithAcceptURLTerms(c.flagAcceptTOS),
@@ -232,7 +248,7 @@ func (c *ServerRunCommand) Run(args []string) int {
 		options = append(options, server.WithHTTP(httpInsecureLn))
 	}
 	auth := false
-	if ac, ok := impl.(server.AuthChecker); ok {
+	if ac, ok := impl.(serverpkg.AuthChecker); ok {
 		options = append(options, server.WithAuthentication(ac))
 		auth = true
 	}
