@@ -7,20 +7,19 @@ import (
 	"strings"
 
 	"github.com/dustin/go-humanize"
-	"github.com/golang/protobuf/ptypes"
-	"github.com/golang/protobuf/ptypes/empty"
 	"github.com/pkg/errors"
 	"github.com/posener/complete"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
+	empty "google.golang.org/protobuf/types/known/emptypb"
 
 	"github.com/hashicorp/waypoint-plugin-sdk/terminal"
 	"github.com/hashicorp/waypoint/internal/clicontext"
 	clientpkg "github.com/hashicorp/waypoint/internal/client"
 	"github.com/hashicorp/waypoint/internal/clierrors"
 	"github.com/hashicorp/waypoint/internal/pkg/flag"
-	pb "github.com/hashicorp/waypoint/internal/server/gen"
 	"github.com/hashicorp/waypoint/internal/version"
+	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 )
 
 type StatusCommand struct {
@@ -267,6 +266,7 @@ func (c *StatusCommand) refreshAppStatus(
 		Application: app.Name,
 		Project:     project.Name,
 	}}
+
 	err := c.DoApp(c.Ctx, func(ctx context.Context, appClient *clientpkg.App) error {
 		// Get our API client
 		client := c.project.Client()
@@ -567,10 +567,15 @@ func (c *StatusCommand) FormatAppStatus(projectTarget string, appTarget string)
 		return err
 	}
 
-	deployHeaders := []string{
+	// deployment and releases use the same headers, with the exception that
+	// deployment lists an additional item for instances count
+	releaseHeaders := []string{
 		"App Name", "Version", "Workspace", "Platform", "Artifact", "Lifecycle State",
 	}
 
+	// Add "Instance Count" for deployment summary headers
+	deployHeaders := append(releaseHeaders, "Instances Count")
+
 	deployTbl := terminal.NewTable(deployHeaders...)
 
 	resourcesHeaders := []string{
@@ -585,7 +590,7 @@ func (c *StatusCommand) FormatAppStatus(projectTarget string, appTarget string)
 	if len(respDeployList.Deployments) > 0 {
 		deployBundle := respDeployList.Deployments[0]
 		deploy := deployBundle.Deployment
-		appDeployStatus := respDeployList.Deployments[0].LatestStatusReport
+		appDeployStatus := deployBundle.LatestStatusReport
 		statusColor := ""
 
 		var details string
@@ -608,6 +613,7 @@ func (c *StatusCommand) FormatAppStatus(projectTarget string, appTarget string)
 			deploy.Component.Name,
 			details,
 			deploy.Status.State.String(),
+			fmt.Sprintf("%d", appDeployStatus.InstancesCount),
 		}
 
 		// Add column data to table
@@ -634,11 +640,7 @@ func (c *StatusCommand) FormatAppStatus(projectTarget string, appTarget string)
 			for _, dr := range appDeployStatus.Resources {
 				var createdTime string
 				if dr.CreatedTime != nil {
-					t, err := ptypes.Timestamp(dr.CreatedTime)
-					if err != nil {
-						return err
-					}
-					createdTime = humanize.Time(t)
+					createdTime = humanize.Time(dr.CreatedTime.AsTime())
 				}
 
 				columns := []string{
@@ -675,7 +677,7 @@ func (c *StatusCommand) FormatAppStatus(projectTarget string, appTarget string)
 	}
 
 	// Same headers as deploy
-	releaseTbl := terminal.NewTable(deployHeaders...)
+	releaseTbl := terminal.NewTable(releaseHeaders...)
 	releaseResourcesTbl := terminal.NewTable(resourcesHeaders...)
 
 	releaseUnimplemented := true
@@ -734,11 +736,7 @@ func (c *StatusCommand) FormatAppStatus(projectTarget string, appTarget string)
 				for _, rr := range appReleaseStatus.Resources {
 					var createdTime string
 					if rr.CreatedTime != nil {
-						t, err := ptypes.Timestamp(rr.CreatedTime)
-						if err != nil {
-							return err
-						}
-						createdTime = humanize.Time(t)
+						createdTime = humanize.Time(rr.CreatedTime.AsTime())
 					}
 
 					columns := []string{
