@@ -4,17 +4,17 @@ import (
 	"context"
 	"errors"
 
-	"github.com/golang/protobuf/proto"
-	"github.com/golang/protobuf/ptypes/any"
 	"github.com/hashicorp/go-argmapper"
 	"github.com/hashicorp/go-hclog"
+	"github.com/hashicorp/opaqueany"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
+	"google.golang.org/protobuf/proto"
 
 	"github.com/hashicorp/waypoint-plugin-sdk/component"
 	"github.com/hashicorp/waypoint/internal/config"
 	"github.com/hashicorp/waypoint/internal/plugin"
-	pb "github.com/hashicorp/waypoint/internal/server/gen"
+	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 )
 
 // Build builds the artifact from source for this app.
@@ -71,6 +71,11 @@ func (a *App) Build(ctx context.Context, optFuncs ...BuildOption) (
 	return build, artifact, err
 }
 
+// Name returns the name of the operation
+func (op *buildOperation) Name() string {
+	return "build"
+}
+
 // BuildOption is used to configure a Build
 type BuildOption func(*buildOptions) error
 
@@ -161,7 +166,7 @@ func (op *buildOperation) Do(ctx context.Context, log hclog.Logger, app *App, _
 				args = append(args, argmapper.Typed(raw))
 
 				if pm, ok := raw.(interface {
-					TypedAny() *any.Any
+					TypedAny() *opaqueany.Any
 				}); ok {
 					any := pm.TypedAny()
 
@@ -198,7 +203,7 @@ func (op *buildOperation) StatusPtr(msg proto.Message) **pb.Status {
 	return &(msg.(*pb.Build).Status)
 }
 
-func (op *buildOperation) ValuePtr(msg proto.Message) (**any.Any, *string) {
+func (op *buildOperation) ValuePtr(msg proto.Message) (**opaqueany.Any, *string) {
 	v := msg.(*pb.Build)
 	if v.Artifact == nil {
 		v.Artifact = &pb.Artifact{}
