@@ -4,16 +4,16 @@ import (
 	"context"
 	"fmt"
 
-	"github.com/golang/protobuf/proto"
-	"github.com/golang/protobuf/ptypes/any"
 	"github.com/hashicorp/go-hclog"
 	"github.com/hashicorp/hcl/v2"
+	"github.com/hashicorp/opaqueany"
+	"google.golang.org/protobuf/proto"
 
 	"github.com/hashicorp/waypoint-plugin-sdk/component"
 	"github.com/hashicorp/waypoint-plugin-sdk/terminal"
 	"github.com/hashicorp/waypoint/internal/config"
 	"github.com/hashicorp/waypoint/internal/plugin"
-	pb "github.com/hashicorp/waypoint/internal/server/gen"
+	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 )
 
 // CanDestroyDeploy returns true if this app supports destroying deployments.
@@ -193,6 +193,11 @@ type deployDestroyOperation struct {
 	Deployment *pb.Deployment
 }
 
+// Name returns the name of the operation
+func (op *deployDestroyOperation) Name() string {
+	return "deployment destroy"
+}
+
 func (op *deployDestroyOperation) Init(app *App) (proto.Message, error) {
 	return op.Deployment, nil
 }
@@ -247,7 +252,7 @@ func (op *deployDestroyOperation) StatusPtr(msg proto.Message) **pb.Status {
 	return nil
 }
 
-func (op *deployDestroyOperation) ValuePtr(msg proto.Message) (**any.Any, *string) {
+func (op *deployDestroyOperation) ValuePtr(msg proto.Message) (**opaqueany.Any, *string) {
 	return nil, nil
 }
 
