@@ -10,7 +10,7 @@ import (
 	componentmocks "github.com/hashicorp/waypoint-plugin-sdk/component/mocks"
 	sdk "github.com/hashicorp/waypoint-plugin-sdk/proto/gen"
 	"github.com/hashicorp/waypoint/internal/config"
-	pb "github.com/hashicorp/waypoint/internal/server/gen"
+	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 )
 
 // Test that a DeployFunc that returns a DeclaredResource results in a resource saved on the deployment response
