@@ -4,17 +4,17 @@ import (
 	"context"
 
 	validation "github.com/go-ozzo/ozzo-validation/v4"
-	"github.com/golang/protobuf/proto"
-	"github.com/golang/protobuf/ptypes/any"
 	"github.com/hashicorp/go-hclog"
 	"github.com/hashicorp/hcl/v2"
+	"github.com/hashicorp/opaqueany"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
+	"google.golang.org/protobuf/proto"
 
 	"github.com/hashicorp/waypoint-plugin-sdk/component"
 	"github.com/hashicorp/waypoint/internal/config"
 	"github.com/hashicorp/waypoint/internal/plugin"
-	pb "github.com/hashicorp/waypoint/internal/server/gen"
+	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 )
 
 // Push pushes the given build to the configured registry. This requires
@@ -154,6 +154,11 @@ func (op *pushBuildOperation) Upsert(
 	return resp.Artifact, nil
 }
 
+// Name returns the name of the operation
+func (op *pushBuildOperation) Name() string {
+	return "push build"
+}
+
 func (op *pushBuildOperation) Do(ctx context.Context, log hclog.Logger, app *App, _ proto.Message) (interface{}, error) {
 	// If we have no registry, we just push the local build.
 	if op.ComponentRegistry == nil {
@@ -173,7 +178,7 @@ func (op *pushBuildOperation) StatusPtr(msg proto.Message) **pb.Status {
 	return &(msg.(*pb.PushedArtifact).Status)
 }
 
-func (op *pushBuildOperation) ValuePtr(msg proto.Message) (**any.Any, *string) {
+func (op *pushBuildOperation) ValuePtr(msg proto.Message) (**opaqueany.Any, *string) {
 	v := msg.(*pb.PushedArtifact)
 	if v.Artifact == nil {
 		v.Artifact = &pb.Artifact{}
