@@ -4,18 +4,18 @@ import (
 	"context"
 	"fmt"
 
-	"github.com/golang/protobuf/proto"
-	"github.com/golang/protobuf/ptypes/any"
 	"github.com/hashicorp/go-hclog"
 	"github.com/hashicorp/hcl/v2"
+	"github.com/hashicorp/opaqueany"
 	"google.golang.org/grpc/codes"
 	"google.golang.org/grpc/status"
+	"google.golang.org/protobuf/proto"
 
 	"github.com/hashicorp/waypoint-plugin-sdk/component"
 	"github.com/hashicorp/waypoint-plugin-sdk/terminal"
 	"github.com/hashicorp/waypoint/internal/config"
 	"github.com/hashicorp/waypoint/internal/plugin"
-	pb "github.com/hashicorp/waypoint/internal/server/gen"
+	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 )
 
 // CanDestroyRelease returns true if this app supports destroying releases.
@@ -236,6 +236,11 @@ func (op *releaseDestroyOperation) Upsert(
 	return resp.Release, nil
 }
 
+// Name returns the name of the operation
+func (op *releaseDestroyOperation) Name() string {
+	return "release destroy"
+}
+
 func (op *releaseDestroyOperation) Do(ctx context.Context, log hclog.Logger, app *App, _ proto.Message) (interface{}, error) {
 	// If we have no releaser then we're done.
 	if op.Component == nil {
@@ -266,7 +271,7 @@ func (op *releaseDestroyOperation) StatusPtr(msg proto.Message) **pb.Status {
 	return nil
 }
 
-func (op *releaseDestroyOperation) ValuePtr(msg proto.Message) (**any.Any, *string) {
+func (op *releaseDestroyOperation) ValuePtr(msg proto.Message) (**opaqueany.Any, *string) {
 	return nil, nil
 }
 
