@@ -14,9 +14,10 @@ import (
 	"google.golang.org/grpc/status"
 
 	configpkg "github.com/hashicorp/waypoint/internal/config"
-	pb "github.com/hashicorp/waypoint/internal/server/gen"
-	serverptypes "github.com/hashicorp/waypoint/internal/server/ptypes"
-	"github.com/hashicorp/waypoint/internal/server/singleprocess"
+	serverpkg "github.com/hashicorp/waypoint/pkg/server"
+	pb "github.com/hashicorp/waypoint/pkg/server/gen"
+	serverptypes "github.com/hashicorp/waypoint/pkg/server/ptypes"
+	"github.com/hashicorp/waypoint/pkg/server/singleprocess"
 )
 
 var testHasGit bool
@@ -27,14 +28,76 @@ func init() {
 	}
 }
 
-func TestRunnerAccept(t *testing.T) {
+func TestRunnerAccept_happy(t *testing.T) {
 	require := require.New(t)
 	ctx := context.Background()
 
 	// Setup our runner
 	client := singleprocess.TestServer(t)
 	runner := TestRunner(t, WithClient(client))
-	require.NoError(runner.Start())
+	require.NoError(runner.Start(ctx))
+
+	// Initialize our app
+	singleprocess.TestApp(t, client, serverptypes.TestJobNew(t, nil).Application)
+
+	// Queue a job
+	queueResp, err := client.QueueJob(ctx, &pb.QueueJobRequest{
+		Job: serverptypes.TestJobNew(t, nil),
+	})
+	require.NoError(err)
+	jobId := queueResp.JobId
+
+	// Accept should complete
+	require.NoError(runner.Accept(ctx))
+
+	// Verify that the job is completed
+	job, err := client.GetJob(ctx, &pb.GetJobRequest{JobId: jobId})
+	require.NoError(err)
+	require.Equal(pb.Job_SUCCESS, job.State)
+}
+
+// Test runner accept and job execution with an adopted token.
+func TestRunnerAccept_adopt(t *testing.T) {
+	require := require.New(t)
+	ctx := context.Background()
+
+	// Start runner
+	serverImpl := singleprocess.TestImpl(t)
+	client := serverpkg.TestServer(t, serverImpl)
+	anonClient := serverpkg.TestServer(t, serverImpl, serverpkg.TestWithToken(""))
+	runner := TestRunner(t,
+		WithClient(anonClient),
+		WithCookie(testCookie(t, client)),
+	)
+	defer runner.Close()
+
+	// Start runner
+	startErr := make(chan error, 1)
+	go func() {
+		startErr <- runner.Start(ctx)
+	}()
+
+	// Wait for runner to show up
+	require.Eventually(func() bool {
+		_, err := client.GetRunner(ctx, &pb.GetRunnerRequest{RunnerId: runner.Id()})
+		return err == nil
+	}, 2*time.Second, 10*time.Millisecond)
+
+	// Adopt the runner
+	_, err := client.AdoptRunner(ctx, &pb.AdoptRunnerRequest{
+		RunnerId: runner.Id(),
+		Adopt:    true,
+	})
+	require.NoError(err)
+
+	// Runner should start
+	select {
+	case <-time.After(5 * time.Second):
+		t.Fatal("runner should start")
+
+	case err := <-startErr:
+		require.NoError(err)
+	}
 
 	// Initialize our app
 	singleprocess.TestApp(t, client, serverptypes.TestJobNew(t, nil).Application)
@@ -62,7 +125,7 @@ func TestRunnerAccept_timeout(t *testing.T) {
 	// Setup our runner
 	client := singleprocess.TestServer(t)
 	runner := TestRunner(t, WithClient(client), WithAcceptTimeout(10*time.Millisecond))
-	require.NoError(runner.Start())
+	require.NoError(runner.Start(ctx))
 
 	// Initialize our app
 	singleprocess.TestApp(t, client, serverptypes.TestJobNew(t, nil).Application)
@@ -73,6 +136,251 @@ func TestRunnerAccept_timeout(t *testing.T) {
 	require.True(errors.Is(err, ErrTimeout))
 }
 
+// Test how accept behaves when the server is down to begin with.
+func TestRunnerAccept_serverDown(t *testing.T) {
+	require := require.New(t)
+	ctx, cancel := context.WithCancel(context.Background())
+	defer cancel()
+
+	// Setup the server
+	restartCh := make(chan struct{})
+	impl := singleprocess.TestImpl(t)
+	client := serverpkg.TestServer(t, impl,
+		serverpkg.TestWithContext(ctx),
+		serverpkg.TestWithRestart(restartCh),
+	)
+
+	// Setup our runner
+	runner := TestRunner(t, WithClient(client))
+	require.NoError(runner.Start(ctx))
+
+	// Initialize our app
+	singleprocess.TestApp(t, client, serverptypes.TestJobNew(t, nil).Application)
+
+	// Queue a job
+	queueResp, err := client.QueueJob(ctx, &pb.QueueJobRequest{
+		Job: serverptypes.TestJobNew(t, nil),
+	})
+	require.NoError(err)
+	jobId := queueResp.JobId
+
+	// Shut it down
+	cancel()
+	ctx, cancel = context.WithCancel(context.Background())
+	defer cancel()
+
+	// Wait to get an unavailable error so we know the server is down
+	require.Eventually(func() bool {
+		_, err := client.GetRunner(ctx, &pb.GetRunnerRequest{RunnerId: "A"})
+		return status.Code(err) == codes.Unavailable
+	}, 5*time.Second, 10*time.Millisecond)
+
+	// Start accept
+	errCh := make(chan error, 1)
+	go func() {
+		errCh <- runner.Accept(ctx)
+	}()
+
+	// The runner should not error
+	select {
+	case <-time.After(100 * time.Millisecond):
+		// Good
+
+	case <-errCh:
+		t.Fatal("runner should not return")
+	}
+
+	// Restart
+	restartCh <- struct{}{}
+
+	// Accept should return
+	select {
+	case err := <-errCh:
+		require.NoError(err)
+
+	case <-time.After(5 * time.Second):
+		t.Fatal("accept never returned")
+	}
+
+	// Verify that the job is completed
+	job, err := client.GetJob(ctx, &pb.GetJobRequest{JobId: jobId})
+	require.NoError(err)
+	require.Equal(pb.Job_SUCCESS, job.State)
+}
+
+// Test how accept behaves when the server is down while waiting for
+// assignment.
+func TestRunnerAccept_serverDownAssign(t *testing.T) {
+	require := require.New(t)
+	ctx, cancel := context.WithCancel(context.Background())
+	defer cancel()
+
+	// New context that will be used for server restart.
+	serverCtx, serverCancel := context.WithCancel(context.Background())
+	defer serverCancel()
+
+	// Setup the server
+	restartCh := make(chan struct{})
+	impl := singleprocess.TestImpl(t)
+	client := serverpkg.TestServer(t, impl,
+		serverpkg.TestWithContext(serverCtx),
+		serverpkg.TestWithRestart(restartCh),
+	)
+
+	// Setup our runner
+	runner := TestRunner(t, WithClient(client))
+	require.NoError(runner.Start(ctx))
+
+	// Initialize our app
+	singleprocess.TestApp(t, client, serverptypes.TestJobNew(t, nil).Application)
+
+	// Start accept
+	errCh := make(chan error, 1)
+	go func() {
+		errCh <- runner.Accept(ctx)
+	}()
+
+	// The runner should not error
+	select {
+	case <-time.After(100 * time.Millisecond):
+		// Good
+
+	case <-errCh:
+		t.Fatal("runner should not return")
+	}
+
+	// Shut it down
+	serverCancel()
+	serverCtx, serverCancel = context.WithCancel(context.Background())
+	defer serverCancel()
+
+	// Wait to get an unavailable error so we know the server is down
+	require.Eventually(func() bool {
+		_, err := client.GetRunner(ctx, &pb.GetRunnerRequest{RunnerId: runner.Id()})
+		return status.Code(err) == codes.Unavailable
+	}, 5*time.Second, 10*time.Millisecond)
+
+	// Restart
+	restartCh <- struct{}{}
+
+	// Queue a job
+	var jobId string
+	require.Eventually(func() bool {
+		queueResp, err := client.QueueJob(ctx, &pb.QueueJobRequest{
+			Job: serverptypes.TestJobNew(t, nil),
+		})
+		if err != nil {
+			return false
+		}
+
+		jobId = queueResp.JobId
+		return true
+	}, 5*time.Second, 10*time.Millisecond)
+
+	// Accept should return
+	select {
+	case err := <-errCh:
+		require.NoError(err)
+
+	case <-time.After(5 * time.Second):
+		t.Fatal("accept never returned")
+	}
+
+	// Verify that the job is completed
+	job, err := client.GetJob(ctx, &pb.GetJobRequest{JobId: jobId})
+	require.NoError(err)
+	require.Equal(pb.Job_SUCCESS, job.State)
+}
+
+// Server down during job execution.
+func TestRunnerAccept_serverDownJobExec(t *testing.T) {
+	require := require.New(t)
+	ctx, cancel := context.WithCancel(context.Background())
+	defer cancel()
+
+	// New context that will be used for server restart.
+	serverCtx, serverCancel := context.WithCancel(context.Background())
+	defer serverCancel()
+
+	// Setup the server
+	restartCh := make(chan struct{})
+	impl := singleprocess.TestImpl(t)
+	client := serverpkg.TestServer(t, impl,
+		serverpkg.TestWithContext(serverCtx),
+		serverpkg.TestWithRestart(restartCh),
+	)
+
+	// Setup our runner
+	runner := TestRunner(t, WithClient(client))
+	require.NoError(runner.Start(ctx))
+
+	// Initialize our app
+	singleprocess.TestApp(t, client, serverptypes.TestJobNew(t, nil).Application)
+
+	// Queue a job
+	queueResp, err := client.QueueJob(ctx, &pb.QueueJobRequest{
+		Job: serverptypes.TestJobNew(t, nil),
+	})
+	require.NoError(err)
+	jobId := queueResp.JobId
+
+	// Make sure our noop operation blocks
+	noopCh := make(chan struct{})
+	runner.noopCh = noopCh
+
+	// Start accept
+	errCh := make(chan error, 1)
+	go func() {
+		errCh <- runner.Accept(ctx)
+	}()
+
+	// The runner should not error
+	select {
+	case <-time.After(100 * time.Millisecond):
+		// Good
+
+	case <-errCh:
+		t.Fatal("runner should not return")
+	}
+
+	// Wait for the job to be running, then we know it is acked.
+	require.Eventually(func() bool {
+		job, err := client.GetJob(ctx, &pb.GetJobRequest{JobId: jobId})
+		return err == nil && job.State == pb.Job_RUNNING
+	}, 5*time.Second, 10*time.Millisecond)
+
+	// Shut the server down
+	serverCancel()
+	serverCtx, serverCancel = context.WithCancel(context.Background())
+	defer serverCancel()
+
+	// Wait to get an unavailable error so we know the server is down
+	require.Eventually(func() bool {
+		_, err := client.GetRunner(ctx, &pb.GetRunnerRequest{RunnerId: runner.Id()})
+		return status.Code(err) == codes.Unavailable
+	}, 5*time.Second, 10*time.Millisecond)
+
+	// Restart
+	restartCh <- struct{}{}
+
+	// Let job complete
+	close(noopCh)
+
+	// Accept should return
+	select {
+	case err := <-errCh:
+		require.NoError(err)
+
+	case <-time.After(5 * time.Second):
+		t.Fatal("accept never returned")
+	}
+
+	// Verify that the job is completed
+	job, err := client.GetJob(ctx, &pb.GetJobRequest{JobId: jobId})
+	require.NoError(err)
+	require.Equal(pb.Job_SUCCESS, job.State)
+}
+
 func TestRunnerAccept_closeCancelesAccept(t *testing.T) {
 	require := require.New(t)
 	ctx, cancel := context.WithTimeout(context.Background(), 5*time.Second)
@@ -81,7 +389,7 @@ func TestRunnerAccept_closeCancelesAccept(t *testing.T) {
 	// Setup our runner
 	client := singleprocess.TestServer(t)
 	runner := TestRunner(t, WithClient(client))
-	require.NoError(runner.Start())
+	require.NoError(runner.Start(ctx))
 
 	// Initialize our app
 	singleprocess.TestApp(t, client, serverptypes.TestJobNew(t, nil).Application)
@@ -114,7 +422,7 @@ func TestRunnerAccept_closeHoldingJob(t *testing.T) {
 	// Setup our runner
 	client := singleprocess.TestServer(t)
 	runner := TestRunner(t, WithClient(client))
-	require.NoError(runner.Start())
+	require.NoError(runner.Start(ctx))
 
 	// Initialize our app
 	singleprocess.TestApp(t, client, serverptypes.TestJobNew(t, nil).Application)
@@ -157,7 +465,7 @@ func TestRunnerAccept_closeWaits(t *testing.T) {
 	// Setup our runner
 	client := singleprocess.TestServer(t)
 	runner := TestRunner(t, WithClient(client))
-	require.NoError(runner.Start())
+	require.NoError(runner.Start(ctx))
 
 	// Initialize our app
 	singleprocess.TestApp(t, client, serverptypes.TestJobNew(t, nil).Application)
@@ -209,7 +517,7 @@ func TestRunnerAccept_cancelContext(t *testing.T) {
 	// Setup our runner
 	client := singleprocess.TestServer(t)
 	runner := TestRunner(t, WithClient(client))
-	require.NoError(runner.Start())
+	require.NoError(runner.Start(ctx))
 
 	// Initialize our app
 	singleprocess.TestApp(t, client, serverptypes.TestJobNew(t, nil).Application)
@@ -247,7 +555,7 @@ func TestRunnerAccept_cancelJob(t *testing.T) {
 	// Setup our runner
 	client := singleprocess.TestServer(t)
 	runner := TestRunner(t, WithClient(client))
-	require.NoError(runner.Start())
+	require.NoError(runner.Start(ctx))
 
 	// Initialize our app
 	singleprocess.TestApp(t, client, serverptypes.TestJobNew(t, nil).Application)
@@ -298,7 +606,7 @@ func TestRunnerAccept_gitData(t *testing.T) {
 	// Setup our runner
 	client := singleprocess.TestServer(t)
 	runner := TestRunner(t, WithClient(client))
-	require.NoError(runner.Start())
+	require.NoError(runner.Start(ctx))
 
 	// Initialize our app
 	singleprocess.TestApp(t, client, serverptypes.TestJobNew(t, nil).Application)
@@ -335,7 +643,7 @@ func TestRunnerAccept_noConfig(t *testing.T) {
 	// Setup our runner
 	client := singleprocess.TestServer(t)
 	runner := TestRunner(t, WithClient(client))
-	require.NoError(runner.Start())
+	require.NoError(runner.Start(ctx))
 
 	// Change our directory to a new temp directory with no config file.
 	testChdir(t, testTempDir(t))
@@ -370,7 +678,7 @@ func TestRunnerAccept_noConfig_serverHcl(t *testing.T) {
 	// Setup our runner
 	client := singleprocess.TestServer(t)
 	runner := TestRunner(t, WithClient(client))
-	require.NoError(runner.Start())
+	require.NoError(runner.Start(ctx))
 
 	// Change our directory to a new temp directory with no config file.
 	testChdir(t, testTempDir(t))
@@ -418,7 +726,7 @@ func TestRunnerAccept_noConfig_serverHclJson(t *testing.T) {
 	// Setup our runner
 	client := singleprocess.TestServer(t)
 	runner := TestRunner(t, WithClient(client))
-	require.NoError(runner.Start())
+	require.NoError(runner.Start(ctx))
 
 	// Change our directory to a new temp directory with no config file.
 	testChdir(t, testTempDir(t))
@@ -467,7 +775,7 @@ func TestRunnerAccept_jobHcl(t *testing.T) {
 	// Setup our runner
 	client := singleprocess.TestServer(t)
 	runner := TestRunner(t, WithClient(client))
-	require.NoError(runner.Start())
+	require.NoError(runner.Start(ctx))
 
 	// Change our directory to a new temp directory with no config file.
 	testChdir(t, testTempDir(t))
