@@ -9,6 +9,7 @@ import (
 	"reflect"
 	"sync"
 
+	"github.com/golang/protobuf/ptypes/empty"
 	"github.com/hashicorp/go-hclog"
 	"github.com/hashicorp/go-multierror"
 	goplugin "github.com/hashicorp/go-plugin"
@@ -21,10 +22,11 @@ import (
 	"github.com/hashicorp/waypoint/internal/appconfig"
 	configpkg "github.com/hashicorp/waypoint/internal/config"
 	"github.com/hashicorp/waypoint/internal/config/variables"
+	"github.com/hashicorp/waypoint/internal/config/variables/formatter"
 	"github.com/hashicorp/waypoint/internal/core"
 	"github.com/hashicorp/waypoint/internal/factory"
 	"github.com/hashicorp/waypoint/internal/plugin"
-	pb "github.com/hashicorp/waypoint/internal/server/gen"
+	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 )
 
 // executeJob executes an assigned job. This will source the data (if necessary),
@@ -33,11 +35,13 @@ func (r *Runner) executeJob(
 	ctx context.Context,
 	log hclog.Logger,
 	ui terminal.UI,
-	job *pb.Job,
+	assignment *pb.RunnerJobStreamResponse_JobAssignment,
 	wd string,
 	clientMutex *sync.Mutex,
 	client pb.Waypoint_RunnerJobStreamClient,
 ) (*pb.Job_Result, error) {
+	job := assignment.Job
+
 	// NOTE(mitchellh; krantzinator): For now, we query the project directly here
 	// since we use it only in case of a missing local waypoint.hcl, and to
 	// collect input variable values set on the server. I can see us moving this
@@ -189,6 +193,8 @@ func (r *Runner) executeJob(
 	pbVars = append(pbVars, vcsVars...)
 	pbVars = append(pbVars, job.Variables...)
 
+	log.Debug("looking to see if there are dynamic variable default values to load")
+
 	// Load any dynamic default values. This happens after the above
 	// because we only load dynamic default values for variables we do
 	// not have values for.
@@ -205,31 +211,75 @@ func (r *Runner) executeJob(
 			)
 		}
 
+		log.Debug("loading default values for dynamic variables")
+
 		dynamicVars, diags := variables.LoadDynamicDefaults(
 			ctx,
 			log,
 			pbVars,
+			assignment.ConfigSources,
 			cfg.InputVariables,
 			appconfig.WithLogger(log),
 			appconfig.WithPlugins(r.configPlugins),
+			appconfig.WithDynamicEnabled(true), // true because we've already determined variables need dynamic defaults
 		)
 		if diags.HasErrors() {
+			log.Warn("failed to load dynamic defaults for variables", "diags", diags)
 			return nil, diags
 		}
+
 		if len(dynamicVars) > 0 {
+			log.Debug("dynamic variables discovered, adding to project variables")
 			// If we have dynamic variable values, we _prepend_ them so that
 			// they have the lowest precedence. In reality, this shouldn't
 			// matter because we only grab dynamic values for vars that have
 			// no value set, but we might as well be careful.
 			pbVars = append(dynamicVars, pbVars...)
+		} else {
+			log.Debug("no dynamic variables found")
 		}
 	}
 
-	// evaluate all variables against the variable blocks we just decoded
-	inputVars, diags := variables.EvaluateVariables(log, pbVars, cfg.InputVariables)
+	// Evaluate all variables against the variable blocks we just decoded:
+	// We grab the server cookie here to pass along for the variables
+	// evaluation to use a salt for sensitive values
+	clientResp, err := r.client.GetServerConfig(ctx, &empty.Empty{})
+	if err != nil {
+		return nil, err
+	}
+	var serverCookie string
+	if clientResp != nil && clientResp.Config != nil {
+		serverCookie = clientResp.Config.Cookie
+	} else {
+		panic("server config does not exist")
+	}
+	// We set both inputVars and jobVars on the project.
+	// inputVars is the set of cty.Values to use in our hcl evaluation
+	// and jobVars is the matching set of variable refs to store on the job that
+	// has sensitive values obfuscated and is used for user-facing feedback/output.
+	inputVars, jobVars, diags := variables.EvaluateVariables(log, pbVars, cfg.InputVariables, serverCookie)
 	if diags.HasErrors() {
 		return nil, diags
 	}
+	// Update the job with the final set of variable values
+	log.Debug("setting final set of variable values on the job")
+	clientMutex.Lock()
+	err = client.Send(&pb.RunnerJobStreamRequest{
+		Event: &pb.RunnerJobStreamRequest_VariableValuesSet_{
+			VariableValuesSet: &pb.RunnerJobStreamRequest_VariableValuesSet{
+				FinalValues: jobVars,
+			},
+		},
+	})
+	clientMutex.Unlock()
+	if err != nil {
+		return nil, err
+	}
+	// log outputtable values
+	output := formatter.ValuesForOutput(jobVars)
+	for name, value := range output {
+		log.Debug("set variable", "name", name, "value", value.Value, "type", value.Type, "source", value.Source)
+	}
 
 	// Build our job info
 	jobInfo := &component.JobInfo{
